@@ -12,6 +12,7 @@ class StationA(Station):
         self,
         air_gap_dest_multi: float = 5,
         air_gap_sample: float = 20,
+        air_gap_lys: float = 10,
         dest_headroom_height: float = 2,
         dest_top_height: float = 5,
         dest_multi_headroom_height: float = 2,
@@ -30,7 +31,7 @@ class StationA(Station):
         logger: Optional[logging.getLoggerClass()] = None,
         lysis_cone_height: float = 16,
         lysis_first: bool = False,
-        lysis_headroom_height: float = 5,
+        lysis_headroom_height: float = 4,
         lysis_rate_aspirate: float = 100,
         lysis_rate_dispense: float = 100,
         lysis_volume: float = 160,
@@ -57,6 +58,7 @@ class StationA(Station):
         source_racks_definition_filepath: str = "",
         source_racks_slots: Tuple[str, ...] = ('2', '3', '5', '6'),
         tempdeck_temp: float = 4,
+        tempdeck_bool: bool = True,
         tipracks_slots: Tuple[str, ...] = ('8', '9', '11'),
         tipracks_slots_20: Tuple[str, ...] = ('7',),
         **kwargs
@@ -126,6 +128,7 @@ class StationA(Station):
         )
         self._air_gap_dest_multi = air_gap_dest_multi
         self._air_gap_sample = air_gap_sample
+        self._air_gap_lys = air_gap_lys
         self._dest_headroom_height = dest_headroom_height
         self._dest_multi_headroom_height = dest_multi_headroom_height
         self._dest_top_height = dest_top_height
@@ -163,14 +166,18 @@ class StationA(Station):
         self._source_racks_slots = source_racks_slots
         self._source_top_height = source_top_height
         self._tempdeck_temp = tempdeck_temp
+        self._tempdeck_bool = tempdeck_bool
         self._tipracks_slots = tipracks_slots
         self._tipracks_slots_20 = tipracks_slots_20
     
     @labware_loader(0, "_tempdeck")
     def load_tempdeck(self):
-        self._tempdeck = self._ctx.load_module('Temperature Module Gen2', '10')
-        if self._tempdeck_temp is not None:
-            self._tempdeck.set_temperature(self._tempdeck_temp)
+        if self._tempdeck_bool:
+            self._tempdeck = self._ctx.load_module('Temperature Module Gen2', '4')
+            if self._tempdeck_temp is not None:
+                self._tempdeck.set_temperature(self._tempdeck_temp)
+        else:
+            pass
     
     @property
     def chilled_tubeblock_content(self) -> str:
@@ -178,10 +185,15 @@ class StationA(Station):
     
     @labware_loader(0.1, "_strips_block")
     def load_strips_block(self):
-        self._strips_block = self._tempdeck.load_labware(
-            'opentrons_96_aluminumblock_generic_pcr_strip_200ul',
-            "chilled tubeblock for {}".format(self.chilled_tubeblock_content.format(""))
-        )
+        if self._tempdeck_bool:
+            self._strips_block = self._tempdeck.load_labware(
+                'opentrons_96_aluminumblock_generic_pcr_strip_200ul',
+                "chilled tubeblock for {}".format(self.chilled_tubeblock_content.format(""))
+            )
+        else:
+            self._strips_block = self._ctx.load_labware('opentrons_96_aluminumblock_generic_pcr_strip_200ul', '4',
+                "chilled tubeblock for {}".format(self.chilled_tubeblock_content.format("")))
+
         self.logger.info("{} {}".format(
             type(self).get_message("using", self._language),
             self.chilled_tubeblock_content.format(self.get_msg_format("chilled tubeblock content with", self.cols_per_strip * self._iec_volume * self._ic_lys_headroom))
@@ -211,7 +223,7 @@ class StationA(Station):
     @labware_loader(3, "_lys_buff")
     def load_lys_buf(self):
         self._lys_buff = self._ctx.load_labware(
-            'opentrons_6_tuberack_falcon_50ml_conical', '4',
+            'opentrons_6_tuberack_falcon_50ml_conical', '7',
             self._lys_buf_name,
         ).wells()[0]
     
@@ -250,8 +262,8 @@ class StationA(Station):
     
     @property
     def initlial_volume_lys(self) -> float:
-        return self._num_samples * self._lysis_volume * self._ic_lys_headroom
-    
+        return len(list(self.non_control_positions(repeat(None)))) * self._lysis_volume * self._ic_lys_headroom
+
     def setup_samples(self):
         self._sources = list(islice(chain.from_iterable(rack.wells() for rack in self._source_racks), self._num_samples))
         self._dests_single = self._dest_plate.wells()[:self._num_samples]
@@ -260,10 +272,13 @@ class StationA(Station):
     
     def setup_lys_tube(self):
         self._lysis_tube = LysisTube(self._lys_buff.diameter / 2, self._lysis_cone_height)
+        self.logger.debug("%s", self._lysis_tube)
         self._lysis_tube.height = self._lysis_headroom_height
         self._lysis_tube.fill(self.initlial_volume_lys)
+        self._lysis_tube.height += self._ic_lys_headroom
         self.logger.info(self.msg_format("lysis geometry", math.ceil(self._lysis_tube.volume), self._lysis_tube.height))
-    
+        self._lysis_tube.height -= self._ic_lys_headroom
+
     def transfer_sample(self, source, dest):
         self.logger.debug("transferring from {} to {}".format(source, dest))
         self.pick_up(self._p_main)
@@ -313,37 +328,40 @@ class StationA(Station):
         sources = sources or self._sources
         dests = dests or self._dests_single
         return filter(lambda t: not self.is_positive_control_well(t[1]), zip(sources, dests))
-    
+
     def transfer_samples(self):
         self._p_main.flow_rate.aspirate = self._sample_aspirate
         self._p_main.flow_rate.dispense = self._sample_dispense
-        
+
         n = len(list(self.non_control_positions()))
         for i, (s, d) in enumerate(self.non_control_positions()):
             if self.run_stage("transfer sample {}/{}".format(i + 1, n)):
                 self.transfer_sample(s, d)
-    
+
     def transfer_lys(self):
         self._p_main.flow_rate.aspirate = self._lysis_rate_aspirate
         self._p_main.flow_rate.dispense = self._lysis_rate_dispense
-        
+
         if self._lysis_first:
             self.pick_up(self._p_main)
         mix = {} if self._lysis_first else {'mix_after': (self._lys_mix_repeats, self._lys_mix_volume)}
         pos = list(self.non_control_positions(repeat(None)))
         n = len(pos)
         for i, (_, dest) in enumerate(pos):
+            h = max(
+                self._lysis_tube.extract(self._lysis_volume * self._ic_lys_headroom),
+                self._lysis_headroom_height
+            )
             if self.run_stage("transfer lysis {}/{}".format(i + 1, n)):
                 if not self._lysis_first:
                     self.pick_up(self._p_main)
                 self.logger.debug("transferring lysis to {}".format(dest))
-                h = max(self._lysis_tube.extract(self._lysis_volume), self._lysis_headroom_height)
                 self.logger.debug("going {} mm deep".format(h))
                 self._p_main.transfer(
                     self._lysis_volume,
                     self._lys_buff.bottom(h),
                     dest.bottom(self._lysis_headroom_height),
-                    air_gap=self._air_gap_sample,
+                    air_gap=self._air_gap_lys,
                     new_tip='never',
                     **mix
                 )
