@@ -8,7 +8,6 @@ class StationBTechnogenetics(StationB):
     _protocol_description = "station B protocol for Technogenetics kit"
 
     def __init__(self,
-                 bind_max_transfer_vol: float = 200,
                  elute_mix_times: int = 15,
                  elution_vol: float = 50,
                  elute_incubate: bool = False,
@@ -28,7 +27,7 @@ class StationBTechnogenetics(StationB):
                  sample_mix_times: float = 10,
                  sample_mix_vol: float = 180,
                  starting_vol: float = 650,
-                 supernatant_removal_height: float = 0.2,
+                 wash_removal_height: float = 0.2,
                  tempdeck_slot: str = '10',
                  tempdeck_temp: float = 60,
                  thermomixer_incubation_time: float = 5,
@@ -55,13 +54,11 @@ class StationBTechnogenetics(StationB):
         :param thermomixer_incubation_time: Time for incubation after thermomixer in minutes 
         """
         super(StationBTechnogenetics, self).__init__(
-            bind_max_transfer_vol=bind_max_transfer_vol,
             elute_mix_times=elute_mix_times,
             elution_vol=elution_vol,
             elute_incubate=elute_incubate,
             flatplate_slot=flatplate_slot,
             starting_vol=starting_vol,
-            supernatant_removal_height=supernatant_removal_height,
             tempdeck_slot=tempdeck_slot,
             tempdeck_temp=tempdeck_temp,
             tipracks_slots=tipracks_slots,
@@ -84,6 +81,7 @@ class StationBTechnogenetics(StationB):
         self._sample_mix_height = sample_mix_height
         self._sample_mix_times = sample_mix_times
         self._sample_mix_vol = sample_mix_vol
+        self._wash_removal_height = wash_removal_height
         self._thermomixer_incubation_time = thermomixer_incubation_time
     
     @labware_loader(5, "_flatplate")
@@ -142,6 +140,7 @@ class StationBTechnogenetics(StationB):
     
     def remove_wash(self, vol):
         self._magdeck.engage(height=self._magheight)
+        self.check()
         self._m300.flow_rate.aspirate = self._supernatant_removal_aspiration_rate
         num_trans, vol_per_trans = uniform_divide(vol, self._wash_max_transfer_vol)
         
@@ -152,7 +151,7 @@ class StationBTechnogenetics(StationB):
                     if self._m300.current_volume > 0:
                         self._m300.dispense(self._m300.current_volume, m.top())  # void air gap if necessary
                     self._m300.move_to(m.center())
-                    self._m300.transfer(vol_per_trans, m.bottom(self._supernatant_removal_height), self._waste, air_gap=self._supernatant_removal_air_gap, new_tip='never')
+                    self._m300.transfer(vol_per_trans, m.bottom(self._wash_removal_height), self._waste, air_gap=self._supernatant_removal_air_gap, new_tip='never')
                     self._m300.air_gap(self._supernatant_removal_air_gap)
                 self.drop(self._m300)
         self._m300.flow_rate.aspirate = self._default_aspiration_rate
@@ -181,13 +180,28 @@ class StationBTechnogenetics(StationB):
         if self.run_stage("mix incubate on"):
             self.delay(self._mix_incubate_on_time, self.get_msg_format("incubate on magdeck", self.get_msg("off")))
         self._magdeck.engage(height=self._magheight)
+        self.check()
         if self.run_stage("mix incubate off"):
             self.delay(self._mix_incubate_off_time, self.get_msg_format("incubate on magdeck", self.get_msg("on")))
         
         self.remove_supernatant(self._starting_vol)
         self.wash(self._wash_1_vol, self.wash1, self._wash_1_times, "wash 1")
+
+        if self.run_stage("spin deepwell"):
+            self._magdeck.disengage()
+            self.dual_pause("spin the deepwell", between=self.set_external)
+            self.set_internal()
+            self._magdeck.engage(height=self._magheight)
+            self.check()
+
+        if self.run_stage("post spin incubation"):
+            self.delay(self._postspin_incubation_time, self.get_msg_format("incubate on magdeck", self.get_msg("on")))
+
+        self.remove_wash(self._remove_wash_vol)
+
         if self.run_stage("remove wash A"):
             self.dual_pause("Check Wash A removal")
+
         self.wash(self._wash_2_vol, self.wash2, self._wash_2_times, "wash 2")
         
         if self.run_stage("spin deepwell"):
@@ -195,6 +209,7 @@ class StationBTechnogenetics(StationB):
             self.dual_pause("spin the deepwell", between=self.set_external)
             self.set_internal()
             self._magdeck.engage(height=self._magheight)
+            self.check()
         
         if self.run_stage("post spin incubation"):
             self.delay(self._postspin_incubation_time, self.get_msg_format("incubate on magdeck", self.get_msg("on")))
@@ -212,6 +227,7 @@ class StationBTechnogenetics(StationB):
             self.set_internal()
         
         self._magdeck.engage(height=self._magheight)
+        self.check()
         if self.run_stage("post thermomixer incubation"):
             self.delay(self._thermomixer_incubation_time, self.get_msg_format("incubate on magdeck", self.get_msg("on")))
         
